/*
 * Copyright (C) 2011, Jamie Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTPARSERS_VMGEntities_FACTORY_H
#define EVENTPARSERS_VMGEntities_FACTORY_H

class Settings;

class QString;

namespace EventParsers
{
	namespace VMGEntities
	{
		class SMSEntity;
		class iReader;

		class Factory
		{
		private:
			Factory() {};

		public:
			static iReader* Instantiate(const Settings &settings, QString& lineData, const SMSEntity* parent);
		};
	}
}

#endif // EVENTPARSERS_VMGEntities_FACTORY_H
